%global pypi_name gunicorn

%bcond_without tests

Name:           python-%{pypi_name}
Version:        22.0.0
Release:        %mkrel 1
Summary:        Python WSGI application server
Group:          Development/Python
License:        MIT
URL:            http://gunicorn.org/
Source0:        %{pypi_source}
BuildArch:      noarch
BuildRequires:  pkgconfig(python3)
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3dist(setuptools)
%if %{with tests}
BuildRequires:  python3dist(aiohttp)
BuildRequires:  python3dist(gevent)
BuildRequires:  python3dist(eventlet)
BuildRequires:  python3dist(coverage)
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pytest-cov)
%endif

%description
Gunicorn ("Green Unicorn") is a Python WSGI HTTP server for UNIX. It uses the
pre-fork worker model, ported from Ruby's Unicorn project. It supports WSGI,
Django, and Paster applications.

%package -n python3-%{pypi_name}
Summary:        Python3 WSGI application server
Group:          Development/Python

%description -n python3-%{pypi_name}
Gunicorn ("Green Unicorn") is a Python3 WSGI HTTP server for UNIX. It uses the
pre-fork worker model, ported from Ruby's Unicorn project. It supports WSGI,
Django, and Paster applications.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files gunicorn

# symlink extra executable names
ln -sr %{buildroot}%{_bindir}/%{pypi_name} %{buildroot}%{_bindir}/%{pypi_name}-3
ln -sr %{buildroot}%{_bindir}/%{pypi_name} %{buildroot}%{_bindir}/%{pypi_name}-%{python3_version}

%if %{with tests}
%check
%pytest
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc NOTICE README.rst THANKS
%{_bindir}/%{pypi_name}
%{_bindir}/%{pypi_name}-3*


%changelog
* Sun Jun 23 2024 papoteur <papoteur> 22.0.0-1.mga9
+ Revision: 2076291
- new version 22.0.0

* Sun Jun 12 2022 guillomovitch <guillomovitch> 20.1.0-3.mga9
+ Revision: 1864034
- rebuild to fix dependencies
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sun Aug 29 2021 wally <wally> 20.1.0-1.mga9
+ Revision: 1743369
- new version 20.1.0

* Tue Mar 23 2021 guillomovitch <guillomovitch> 20.0.4-2.mga9
+ Revision: 1708426
- rebuild for python 3.9

* Mon Aug 24 2020 bcornec <bcornec> 20.0.4-1.mga8
+ Revision: 1618471
- Update to upstream python-gunicorn 20.0.4

* Fri May 15 2020 ngompa <ngompa> 19.9.0-5.mga8
+ Revision: 1583810
- Add versioned executable names

* Sun Feb 16 2020 umeabot <umeabot> 19.9.0-4.mga8
+ Revision: 1532727
- Mageia 8 Mass Rebuild

* Tue Sep 17 2019 tv <tv> 19.9.0-3.mga8
+ Revision: 1442919
- rebuild for python-3.8

* Fri Aug 30 2019 wally <wally> 19.9.0-2.mga8
+ Revision: 1435656
- drop python2 support

* Sat Jan 12 2019 shlomif <shlomif> 19.9.0-1.mga7
+ Revision: 1355377
- Rebuild for python3 3.7
+ tv <tv>
- rebuild with python 3.7

* Thu Sep 20 2018 umeabot <umeabot> 19.6.0-6.mga7
+ Revision: 1288931
- Mageia 7 Mass Rebuild

* Tue May 08 2018 daviddavid <daviddavid> 19.6.0-5.mga7
+ Revision: 1227703
- rename python-gunicorn to python2-gunicorn
- add BR pytest-cov
- use new python provides

* Wed Oct 04 2017 tv <tv> 19.6.0-4.mga7
+ Revision: 1168844
- add BR on python2dist(mock) thus fixing build

* Sat Aug 05 2017 pterjan <pterjan> 19.6.0-3.mga7
+ Revision: 1135444
- Rebuild for python 3.6

* Sun Jan 08 2017 daviddavid <daviddavid> 19.6.0-2.mga6
+ Revision: 1080669
- rebuild against python(3)-pytest
- use new pyton macros

* Mon Jan 02 2017 bcornec <bcornec> 19.6.0-1.mga6
+ Revision: 1079643
- update to upstream python-gunicorn 19.6.0

* Fri Feb 19 2016 umeabot <umeabot> 19.1.1-7.mga6
+ Revision: 970881
- Mageia 6 Mass Rebuild

* Sat Oct 10 2015 tv <tv> 19.1.1-6.mga6
+ Revision: 888795
- rebuild for python 3.5

* Wed Oct 15 2014 umeabot <umeabot> 19.1.1-5.mga5
+ Revision: 743177
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 19.1.1-4.mga5
+ Revision: 728711
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 19.1.1-3.mga5
+ Revision: 688070
- Mageia 5 Mass Rebuild

* Wed Sep 10 2014 bcornec <bcornec> 19.1.1-2.mga5
+ Revision: 674525
- Forgot to bump the rel tag for previous modifs.
- Adds support for python2 build for gunicorn to easy docker-io-registry build

* Wed Sep 03 2014 bcornec <bcornec> 19.1.1-1.mga5
+ Revision: 671196
- Fix Group: entry in spec file to be Mageia compliant
- Update sha1.lst
- Import python-gunicorn from Fedora with Mageia adaptations
- Created package structure for python-gunicorn.

